package BPpath.hanzi;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.os.Environment;
import android.os.Handler;
import android.view.Menu;
import android.view.View;
import android.webkit.WebView;
import android.widget.Toast;
import java.io.File;
import java.util.Arrays;
import java.util.List;
import BPpath.hanzi.flashcards.*;

 
/*
 * BoilerPlate.java is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * author: R. Earle Harris (evsiz@this-voice.org) copyrighted 2014
 *
 */

public class BoilerPlate extends Activity {
	public String deck;
	public String headers;
	public String sizes;
	public String record = "";
	public String set = "All"; 
	public String sides; // a = answer, q = front, x = unused
	public String[] cards; // lines from asset data files
	public String flashcard_dir = "";

	public static final int SELECT_DECK = 1;
	public static final int SELECT_CARDS = 2;
	public static final int SELECT_SIDES = 3;
	public static final int STUDY = 4;
	public static final int TEST = 5;

	public static final int MENU_STUDY = Menu.FIRST;
	public static final int MENU_TEST = Menu.FIRST + 1;
	public static final int MENU_EXIT = Menu.FIRST + 2;

	public int MODE;
	public static final int PENDING_MODE = -1;
	public static final int STUDY_MODE = 0;
	public static final int TEST_MODE = 1;

	public PRAFileHandler fhandler = new PRAFileHandler(this);

	private WebView webview;

	private void findViews() {
		webview = (WebView) findViewById(R.id.webView1);
	}

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		String appname = getResources().getString(R.string.app_name);
		if (appname.matches("Flashcard Mojo")){
			File sdCard = Environment.getExternalStorageDirectory();
			flashcard_dir = sdCard.getAbsolutePath() + "/BoilerPlate/";
			File dir = new File(flashcard_dir);
			dir.mkdirs();
			File readme = new File(flashcard_dir, "read.me");
			if (readme.length() == 0) {
				fhandler.copyAssets(flashcard_dir, ".txt");
				fhandler.copyAssets(flashcard_dir, ".me");
			}
		}
		// set view and pending mode
		setContentView(R.layout.activity_flashcard_mojo);
		findViews();
		webview.setScrollBarStyle(View.SCROLLBARS_INSIDE_OVERLAY);
		webview.getSettings().setBuiltInZoomControls(true);
		webview.getSettings().setSupportZoom(true);
		webview.loadUrl("file:///android_asset/index.html");
		MODE = PENDING_MODE;

		// show eula on first use
		new SimpleEula(this).show();
	}

	@Override
	public void onActivityResult(int requestCode, int resultCode, Intent intent) {
		super.onActivityResult(requestCode, resultCode, intent);
		if (intent != null) {

			if (resultCode == RESULT_OK) {
				switch (requestCode) {
				case SELECT_DECK:
					deck = intent.getStringExtra("DECK"); // deck now path2file
					headers = intent.getStringExtra("HEADERS");
					sizes = intent.getStringExtra("SIZES");
					// Toast.makeText(this, "Back with deck: " + deck,
					// Toast.LENGTH_SHORT).show();
					if (MODE == STUDY_MODE) {
						Intent i = new Intent(this, CardSelection.class);
						i.putExtra("DECK", deck);
						startActivityForResult(i, SELECT_CARDS);
					} else {
						Intent j = new Intent(this, SideSelection.class);
						j.putExtra("HEADERS", headers);
						j.putExtra("MODE", MODE);
						startActivityForResult(j, SELECT_SIDES);
					}
					break;
				case SELECT_CARDS:
					cards = intent.getStringArrayExtra("SELECTION");
					set = intent.getStringExtra("SET"); 
					if (deck.startsWith("last_test")){
						headers = intent.getStringExtra("HEADERS");
						sizes = intent.getStringExtra("SIZES");
					}
					// for (String s : cards) {
					// Toast.makeText(this, s, Toast.LENGTH_SHORT).show();
					// }
					Intent j = new Intent(this, SideSelection.class);
					j.putExtra("HEADERS", headers);
					j.putExtra("MODE", MODE);
					startActivityForResult(j, SELECT_SIDES);

					break;
				case SELECT_SIDES:
					sides = intent.getStringExtra("SIDES");
					// Toast.makeText(this, "Back with sides: "+sides,
					// Toast.LENGTH_SHORT).show();
					if (MODE == STUDY_MODE) {
						Intent k = new Intent(this, Study.class);
						k.putExtra("DECK", deck); 
						if (set == null){ set = ""; }
						k.putExtra("SET", set); 
						k.putExtra("SIDES", sides);
						k.putExtra("CARDS", cards);
						k.putExtra("HEADERS", headers);
						k.putExtra("SIZES", sizes);
						startActivityForResult(k, STUDY);
					} else {
						Intent l = new Intent(this, Test.class);
						l.putExtra("SIDES", sides);
						l.putExtra("DECK", deck);
						l.putExtra("HEADERS", headers);
						l.putExtra("SIZES", sizes);
						startActivityForResult(l, TEST);
					}
					break;
				case STUDY:
					sides = intent.getStringExtra("SIDES");
					record = intent.getStringExtra("RECORD");
					// Toast.makeText(this, "Back with sides: "+sides,
					// Toast.LENGTH_SHORT).show();
					if (MODE == STUDY_MODE) {
						Intent m = new Intent(this, SideSelection.class);
						m.putExtra("HEADERS", headers);
						m.putExtra("MODE", MODE);
						startActivityForResult(m, SELECT_SIDES);
					}
					break;
				default:
					MODE = PENDING_MODE;
				}
			} else { // RESULT_CANCELED
				if ((MODE == STUDY_MODE) && (requestCode == SELECT_SIDES)) {
					List<String> top = Arrays.asList(record); 
					fhandler.writeToTopOfFile(top, "Memo.txt");
				}
				MODE = PENDING_MODE;
			}
		}
	}

	/**
	 * DeckSelection => CardSelection => SideSelection => Study
	 */
	public void modeStudy(View view) {
		MODE = STUDY_MODE;
		// get category section and card sides
		Intent i = new Intent(this, DeckSelection.class);
		startActivityForResult(i, SELECT_DECK);
	}

	/**
	 * DeckSelection => SideSelection => Test
	 */
	public void modeTest(View view) {
		MODE = TEST_MODE;
		Intent i = new Intent(this, DeckSelection.class);
		i.putExtra("MODE", TEST_MODE);
		startActivityForResult(i, SELECT_DECK);
	}

	public void memo(View view) {	
		Intent i = new Intent(this, Memo.class);
		startActivity(i);
	}

	private boolean doubleBackPressedOnce = false;

	@Override
	public void onBackPressed() {
		if (doubleBackPressedOnce) {
			super.onBackPressed();
			return;
		}
		doubleBackPressedOnce = true;
		Toast.makeText(this, R.string.exit_bkbtn, Toast.LENGTH_SHORT).show();
		new Handler().postDelayed(new Runnable() {

			@Override
			public void run() {
				doubleBackPressedOnce = false;
			}
		}, 2000);
	}

}
