package BPpath.hanzi.flashcards;

import android.app.ListActivity;
import android.content.Intent;
import android.os.Bundle;
import android.os.Environment;
import android.view.Gravity;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;
import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import BPpath.hanzi.PRAFileHandler;
import BPpath.hanzi.R;

 
/*
 * DeckSelection.java is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * author: R. Earle Harris (evsiz@this-voice.org) copyrighted 2014
 *
 */

public class DeckSelection extends ListActivity {
	
	public PRAFileHandler fhandler = new PRAFileHandler(this);
	public Map<String, String> dbs = new HashMap<String, String>();
	public int MODE;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		Intent origin = this.getIntent();
		MODE = origin.getIntExtra("MODE", 0);
		super.onCreate(savedInstanceState);
		final String[] list = buildList();
		setContentView(R.layout.activity_deck_selection);
		setListAdapter(new ArrayAdapter<String>(this,
				R.layout.pra_list_item, list));

		ListView listView = getListView();
		listView.setTextFilterEnabled(true);

		listView.setOnItemClickListener(new OnItemClickListener() {
			public void onItemClick(AdapterView<?> parent, View view,
					int position, long id) {
				String result = ((TextView) view).getText().toString();
				String file = dbs.get(result);
				String[] allCards;
				String headers = "";
				String sizes = "";
				String appname = getResources().getString(R.string.app_name);
				if (file.startsWith("last_test")){
					allCards = fhandler.getFileAsArray(file);
					headers = "";
					sizes = "";
				} else if (file.matches("nud")){	
					Intent inud = new Intent();
					setResult(RESULT_CANCELED, inud);
					finish();
				} else if (appname.matches("Ziji Zidian")){
					allCards = fhandler.getExtFileAsArray("", file);
				} else {
					allCards = fhandler.getAssetAsArray(file);
					headers = allCards[0];
					sizes = allCards[1];
				}
				Intent intent = new Intent();
				intent.putExtra("DECK", file);
				if (!appname.matches("Ziji Zidian")){
					intent.putExtra("HEADERS", headers);
					intent.putExtra("SIZES", sizes);
				}
				setResult(RESULT_OK, intent); // we return filename of deck
				finish();
			}
		});
	}

	private String[] buildList() {
		List<String> alist;
		String appname = getResources().getString(R.string.app_name);
		if (appname.matches("Ziji Zidian")){
			File sdCard = Environment.getExternalStorageDirectory();
			String flashcard_dir = sdCard.getAbsolutePath() + "/ZijiZidian/";
			File dir = new File(flashcard_dir);
			File[] files = dir.listFiles();
			if (files.length == 0){
				alist = new ArrayList<String>();
				alist.add("No User Data");
				dbs.put("No User Data", "nud");
			} else {
				alist = new ArrayList<String>();
				for (File inFile : files) {
					String fname = inFile.toString();
					if (!fname.contains(".txt")) { continue; }
					String tmp = fname;
					fname = fname.replace(flashcard_dir, "");
					fname = fname.replace(".txt", "");
					fname = fname.replace('_', ' ');
					fname = fname.substring(0,1).toUpperCase() + fname.substring(1);
					alist.add(fname);
					dbs.put(fname, tmp);
				}
			}
		} else {
			String[] files = fhandler.listAssets(".txt");
			String name = "";
			alist = new ArrayList<String>();
			for (String f : files) {
				name = f.replace('_', ' ');
				name = name.replace(".txt", "");
				// TODO locale for next line
				name = Character.toUpperCase(name.charAt(0)) + name.substring(1);
				alist.add(name);
				dbs.put(name, f);
			}
		}

		Collections.sort(alist);

		if (MODE == 0){
			File internal = getFilesDir();
			File[] files = internal.listFiles();
			String name = null;
			String fname = null;
			String[] tokens = null;
			for (File inFile : files) {
				fname = inFile.toString();
				tokens	= fname.split("/");
				fname = tokens[tokens.length - 1];
				if (fname.startsWith("last_test")){
					name = fname.replace('_', ' ');
					name = name.replace(".txt", "");
					name = name.replace("last test", "Last Test:");
					alist.add(name);
					dbs.put(name, fname);
				}
			}
		}

		String[] list = new String[alist.size()];
		alist.toArray(list);
		return list;
		}

	@Override
	public void onBackPressed() {
		Intent intent = new Intent();
		setResult(RESULT_CANCELED, intent);
		finish();
	}

    @Override
    protected void onResume() {
        super.onResume();
    }

    // length gets Toast.LENGTH_LONG|SHORT
	public void toaster(String text, int length) {
		Toast t = Toast.makeText(this, text, length);
		t.setGravity(Gravity.CENTER, 0, 0);
		t.show();
	}

}
